@@ -1,4 +1,4 @@
-package Mojolicious::Plugin::Config::Structured::Bootstrap 0.02;
+package Mojolicious::Plugin::Config::Structured::Bootstrap 0.03;
 use v5.26;
 use warnings;
 
@@ -11,6 +11,7 @@ use Hash::Merge;
 use HTTP::Status     qw(:constants status_message);
 use List::MoreUtils  qw(arrayify);
 use Module::Loadable qw(module_loadable);
+use DateTime::Format::MySQL;
 use Readonly;
 use Syntax::Keyword::Try;
 
@@ -164,11 +165,13 @@ sub register($self, $app, $app_config) {
           $c->redirect_to($url);
         },
         on_login => sub ($c, $u) {
-          $u->update({last_login_at    => \["NOW()"]});
-          $u->update({last_activity_at => \["NOW()"]});
+          my $now = DateTime::Format::MySQL->format_datetime(DateTime->now(time_zone => 'local'));
+          $u->update({last_login_at    => $now});
+          $u->update({last_activity_at => $now});
         },
         on_activity => sub ($c, $u) {
-          $u->update({last_activity_at => \["NOW()"]});
+          my $now = DateTime::Format::MySQL->format_datetime(DateTime->now(time_zone => 'local'));
+          $u->update({last_activity_at => $now});
         }
       }
     }
@@ -199,7 +202,9 @@ sub register($self, $app, $app_config) {
               my $u = $c->authn->current_user();
               return $c->$cb('User not authenticated')  unless (defined($u));
               return $c->$cb('User email not verified') unless ($u->email_verified);
-              return $c->$cb()                          unless ($scopes->@*);
+              return $c->$cb('User disabled/deleted')
+                if ($u->can('deleted_at') && defined($u->deleted_at) && $u->deleted_at < DateTime->now());
+              return $c->$cb() unless ($scopes->@*);
               return $c->$cb() if (intersect($scopes->@*, $c->authn->current_user_roles->@*));
               return $c->$cb('User not authorized');
             } catch ($e) {
